# GPTConnect

GPTConnect is a Python package that simplifies the use of the new functions feature of ChatGPT by OpenAI. It provides an easy-to-use framework for creating, defining and interacting with GPT functions, making your development process smoother and more efficient.

## Features

- Simplified and intuitive decorator based system to define GPT functions.
- Function groups system that allow easy integration of multiple commands at a time
- More feautures coming soon! This package is only in early stages of development.

## Demo
[demo.py](https://github.com/SleepyStew/gptconnect/blob/master/demo.py)
